@@ -18,7 +18,7 @@ use utf8;
 ## use critic (Modules::RequireExplicitPackage)
 
 package WebFetch;
-$WebFetch::VERSION = '0.15.0';
+$WebFetch::VERSION = '0.15.1';
 
 use Carp qw(croak);
 use Getopt::Long;
@@ -760,7 +760,11 @@ sub run
     }
 
     debug "run before save";
-    my $result = $obj->save();
+    my $result      = $obj->save();
+    my $result_code = $result ? 0 : 1;
+    if ($test_probe_ref) {
+        $test_probe_ref->{result} = $result_code;
+    }
 
     # check for errors, throw exception to report errors per savable item
     if ( not $result ) {
@@ -779,7 +783,7 @@ sub run
         }
     }
 
-    return $result ? 0 : 1;
+    return $result_code;
 }
 
 sub do_actions
@@ -1831,7 +1835,7 @@ WebFetch - Perl module to download/fetch and save information from the Web
 
 =head1 VERSION
 
-version 0.15.0
+version 0.15.1
 
 =head1 SYNOPSIS
 
